==> julia-git-abstractalgebra-src-0.47.6-1-any.pkg.tar.zst: usr/share/julia/arch-site/AbstractAlgebra/src/generic/imports.jl <==
import LinearAlgebra: norm
import LinearAlgebra: rank
import LinearAlgebra: tr

using Random: Random, AbstractRNG, randperm!, SamplerTrivial
using RandomExtensions: RandomExtensions, make, Make, Make2, Make3, Make4
using SparseArrays: sparse, spzeros

import Base: !=
import Base: &
import Base: *
import Base: +
import Base: -
import Base: /
import Base: //
import Base: <
import Base: <<
import Base: <=
import Base: ==
import Base: >
import Base: >=
import Base: >>
import Base: Matrix
import Base: Rational
import Base: ^
import Base: abs
import Base: ceil
import Base: conj
import Base: convert
import Base: copy
import Base: deepcopy
import Base: deepcopy_internal
import Base: exponent
import Base: floor
import Base: gcd
import Base: gcdx
import Base: getindex
import Base: hash
import Base: intersect
import Base: invmod
import Base: isapprox
import Base: isempty
import Base: isequal
import Base: isless
import Base: isone
import Base: iszero
import Base: lcm
import Base: length
import Base: mod
import Base: one
import Base: parent
import Base: parse
import Base: precision
import Base: rand
import Base: rem
import Base: reverse
import Base: reverse!
import Base: setindex!
import Base: show
import Base: sign
import Base: similar
import Base: size
import Base: string
import Base: transpose
import Base: truncate
import Base: vcat
import Base: xor
import Base: zero
import Base: zeros
import Base: |
import Base: ~

using ..AbstractAlgebra

import ..AbstractAlgebra: @attributes
import ..AbstractAlgebra: @enable_all_show_via_expressify
import ..AbstractAlgebra: @show_name
import ..AbstractAlgebra: @show_special
import ..AbstractAlgebra: CacheDictType
import ..AbstractAlgebra: CycleDec
import ..AbstractAlgebra: Dedent
import ..AbstractAlgebra: Field
import ..AbstractAlgebra: FieldElement
import ..AbstractAlgebra: GFElem
import ..AbstractAlgebra: Indent
import ..AbstractAlgebra: Integers
import ..AbstractAlgebra: Lowercase
import ..AbstractAlgebra: LowercaseOff
import ..AbstractAlgebra: Map
import ..AbstractAlgebra: NCRing
import ..AbstractAlgebra: NCRingElem
import ..AbstractAlgebra: NCRingElement
import ..AbstractAlgebra: O
import ..AbstractAlgebra: Perm
import ..AbstractAlgebra: Ring
import ..AbstractAlgebra: RingElem
import ..AbstractAlgebra: RingElement
import ..AbstractAlgebra: _can_solve_with_solution_fflu
import ..AbstractAlgebra: _can_solve_with_solution_lu
import ..AbstractAlgebra: add!
import ..AbstractAlgebra: addmul!
import ..AbstractAlgebra: base_ring
import ..AbstractAlgebra: base_ring_type
import ..AbstractAlgebra: canonical_unit
import ..AbstractAlgebra: change_base_ring
import ..AbstractAlgebra: characteristic
import ..AbstractAlgebra: check_base_ring
import ..AbstractAlgebra: check_parent
import ..AbstractAlgebra: codomain
import ..AbstractAlgebra: coeff
import ..AbstractAlgebra: coeff!
import ..AbstractAlgebra: coefficient_ring
import ..AbstractAlgebra: coefficient_ring_type
import ..AbstractAlgebra: coefficients
import ..AbstractAlgebra: coefficients_of_univariate
import ..AbstractAlgebra: compose
import ..AbstractAlgebra: constant_coefficient
import ..AbstractAlgebra: content
import ..AbstractAlgebra: data
import ..AbstractAlgebra: deflate
import ..AbstractAlgebra: deflation
import ..AbstractAlgebra: degree
import ..AbstractAlgebra: degrees
import ..AbstractAlgebra: degrees_range
import ..AbstractAlgebra: denominator
import ..AbstractAlgebra: derivative
import ..AbstractAlgebra: div
import ..AbstractAlgebra: divexact
import ..AbstractAlgebra: divides
import ..AbstractAlgebra: divrem
import ..AbstractAlgebra: domain
import ..AbstractAlgebra: elem_type
import ..AbstractAlgebra: evaluate
import ..AbstractAlgebra: exp
import ..AbstractAlgebra: exponent_vector
import ..AbstractAlgebra: exponent_vectors
import ..AbstractAlgebra: exponent_vector!
import ..AbstractAlgebra: expressify
import ..AbstractAlgebra: factor
import ..AbstractAlgebra: factor_squarefree
import ..AbstractAlgebra: gen
import ..AbstractAlgebra: gens
import ..AbstractAlgebra: get_cached!
import ..AbstractAlgebra: hom
import ..AbstractAlgebra: ideal_type
import ..AbstractAlgebra: identity_matrix
import ..AbstractAlgebra: image
import ..AbstractAlgebra: image_fn
import ..AbstractAlgebra: inflate
import ..AbstractAlgebra: integral
import ..AbstractAlgebra: inv
import ..AbstractAlgebra: inv!
import ..AbstractAlgebra: is_constant
import ..AbstractAlgebra: is_divisible_by
import ..AbstractAlgebra: is_domain_type
import ..AbstractAlgebra: is_exact_type
import ..AbstractAlgebra: is_finite
import ..AbstractAlgebra: is_gen
import ..AbstractAlgebra: is_monomial
import ..AbstractAlgebra: is_nilpotent
import ..AbstractAlgebra: is_perfect
import ..AbstractAlgebra: is_power
import ..AbstractAlgebra: is_square
import ..AbstractAlgebra: is_squarefree
import ..AbstractAlgebra: is_square_with_sqrt
import ..AbstractAlgebra: is_term
import ..AbstractAlgebra: is_terse
import ..AbstractAlgebra: is_trivial
import ..AbstractAlgebra: is_unit
import ..AbstractAlgebra: is_univariate
import ..AbstractAlgebra: is_univariate_with_data
import ..AbstractAlgebra: is_zero_divisor
import ..AbstractAlgebra: is_zero_divisor_with_annihilator
import ..AbstractAlgebra: isreduced_form
import ..AbstractAlgebra: JuliaRingElement
import ..AbstractAlgebra: leading_coefficient
import ..AbstractAlgebra: leading_exponent_vector
import ..AbstractAlgebra: leading_monomial
import ..AbstractAlgebra: leading_term
import ..AbstractAlgebra: log
import ..AbstractAlgebra: map_coefficients
import ..AbstractAlgebra: matrix
import ..AbstractAlgebra: max_precision
import ..AbstractAlgebra: minpoly
import ..AbstractAlgebra: modulus
import ..AbstractAlgebra: monomials
import ..AbstractAlgebra: monomial!
import ..AbstractAlgebra: mul!
import ..AbstractAlgebra: mul_classical
import ..AbstractAlgebra: mul_karatsuba
import ..AbstractAlgebra: mullow
import ..AbstractAlgebra: neg!
import ..AbstractAlgebra: number_of_columns
import ..AbstractAlgebra: number_of_generators
import ..AbstractAlgebra: number_of_rows
import ..AbstractAlgebra: number_of_variables
import ..AbstractAlgebra: numerator
import ..AbstractAlgebra: one!
import ..AbstractAlgebra: order
import ..AbstractAlgebra: parent_type
import ..AbstractAlgebra: pol_length
import ..AbstractAlgebra: pow!
import ..AbstractAlgebra: preimage
import ..AbstractAlgebra: pretty
import ..AbstractAlgebra: pretty_sort
import ..AbstractAlgebra: primpart
import ..AbstractAlgebra: promote_rule
import ..AbstractAlgebra: pseudorem
import ..AbstractAlgebra: reduce!
import ..AbstractAlgebra: reduced_form
import ..AbstractAlgebra: remove
import ..AbstractAlgebra: renormalize!
import ..AbstractAlgebra: set_coefficient!
import ..AbstractAlgebra: set_length!
import ..AbstractAlgebra: set_precision!
import ..AbstractAlgebra: set_valuation!
import ..AbstractAlgebra: shift_left
import ..AbstractAlgebra: shift_right
import ..AbstractAlgebra: snf
import ..AbstractAlgebra: sqrt
import ..AbstractAlgebra: sub!
import ..AbstractAlgebra: submul!
import ..AbstractAlgebra: symbols
import ..AbstractAlgebra: tail
import ..AbstractAlgebra: term_degree
import ..AbstractAlgebra: terms
import ..AbstractAlgebra: term!
import ..AbstractAlgebra: terms_degrees
import ..AbstractAlgebra: terse
import ..AbstractAlgebra: to_univariate
import ..AbstractAlgebra: trailing_coefficient
import ..AbstractAlgebra: unit
import ..AbstractAlgebra: use_karamul
import ..AbstractAlgebra: valuation
import ..AbstractAlgebra: var
import ..AbstractAlgebra: var_index
import ..AbstractAlgebra: var_indices
import ..AbstractAlgebra: vars
import ..AbstractAlgebra: vector_space_dim
import ..AbstractAlgebra: zero!

==> julia-git-abstractalgebra-src-0.48.3-1-any.pkg.tar.zst: usr/share/julia/arch-site/AbstractAlgebra/src/generic/imports.jl <==
import LinearAlgebra: norm
import LinearAlgebra: rank
import LinearAlgebra: tr

using Random: Random, AbstractRNG, randperm!, SamplerTrivial
using RandomExtensions: RandomExtensions, make, Make, Make2, Make3, Make4
using SparseArrays: sparse, spzeros

import Base: !=
import Base: &
import Base: *
import Base: +
import Base: -
import Base: /
import Base: //
import Base: <
import Base: <<
import Base: <=
import Base: ==
import Base: >
import Base: >=
import Base: >>
import Base: Matrix
import Base: Rational
import Base: ^
import Base: abs
import Base: ceil
import Base: conj
import Base: convert
import Base: copy
import Base: deepcopy
import Base: deepcopy_internal
import Base: exponent
import Base: floor
import Base: gcd
import Base: gcdx
import Base: getindex
import Base: hash
import Base: intersect
import Base: invmod
import Base: isapprox
import Base: isempty
import Base: isequal
import Base: isless
import Base: isone
import Base: iszero
import Base: lcm
import Base: length
import Base: mod
import Base: one
import Base: parent
import Base: parse
import Base: precision
import Base: rand
import Base: rem
import Base: reverse
import Base: reverse!
import Base: setindex!
import Base: show
import Base: sign
import Base: similar
import Base: size
import Base: string
import Base: transpose
import Base: truncate
import Base: vcat
import Base: xor
import Base: zero
import Base: zeros
import Base: |
import Base: ~

using ..AbstractAlgebra

import ..AbstractAlgebra: @attributes
import ..AbstractAlgebra: @enable_all_show_via_expressify
import ..AbstractAlgebra: @show_name
import ..AbstractAlgebra: @show_special
import ..AbstractAlgebra: CacheDictType
import ..AbstractAlgebra: CycleDec
import ..AbstractAlgebra: Dedent
import ..AbstractAlgebra: Field
import ..AbstractAlgebra: FieldElement
import ..AbstractAlgebra: GFElem
import ..AbstractAlgebra: Indent
import ..AbstractAlgebra: Integers
import ..AbstractAlgebra: Lowercase
import ..AbstractAlgebra: LowercaseOff
import ..AbstractAlgebra: Map
import ..AbstractAlgebra: NCRing
import ..AbstractAlgebra: NCRingElem
import ..AbstractAlgebra: NCRingElement
import ..AbstractAlgebra: O
import ..AbstractAlgebra: Perm
import ..AbstractAlgebra: Ring
import ..AbstractAlgebra: RingElem
import ..AbstractAlgebra: RingElement
import ..AbstractAlgebra: _can_solve_with_solution_fflu
import ..AbstractAlgebra: _can_solve_with_solution_lu
import ..AbstractAlgebra: add!
import ..AbstractAlgebra: addmul!
import ..AbstractAlgebra: base_ring
import ..AbstractAlgebra: base_ring_type
import ..AbstractAlgebra: canonical_unit
import ..AbstractAlgebra: change_base_ring
import ..AbstractAlgebra: characteristic
import ..AbstractAlgebra: check_base_ring
import ..AbstractAlgebra: check_parent
import ..AbstractAlgebra: codomain
import ..AbstractAlgebra: coeff
import ..AbstractAlgebra: coeff!
import ..AbstractAlgebra: coefficient_ring
import ..AbstractAlgebra: coefficient_ring_type
import ..AbstractAlgebra: coefficients
import ..AbstractAlgebra: coefficients_of_univariate
import ..AbstractAlgebra: compose
import ..AbstractAlgebra: constant_coefficient
import ..AbstractAlgebra: content
import ..AbstractAlgebra: data
import ..AbstractAlgebra: deflate
import ..AbstractAlgebra: deflation
import ..AbstractAlgebra: degree
import ..AbstractAlgebra: degrees
import ..AbstractAlgebra: degrees_range
import ..AbstractAlgebra: denominator
import ..AbstractAlgebra: dense_matrix_type
import ..AbstractAlgebra: derivative
import ..AbstractAlgebra: div
import ..AbstractAlgebra: divexact
import ..AbstractAlgebra: divides
import ..AbstractAlgebra: divrem
import ..AbstractAlgebra: domain
import ..AbstractAlgebra: elem_type
import ..AbstractAlgebra: evaluate
import ..AbstractAlgebra: evaluation_points
import ..AbstractAlgebra: exp
import ..AbstractAlgebra: exponent_vector
import ..AbstractAlgebra: exponent_vectors
import ..AbstractAlgebra: exponent_vector!
import ..AbstractAlgebra: expressify
import ..AbstractAlgebra: factor
import ..AbstractAlgebra: factor_squarefree
import ..AbstractAlgebra: gen
import ..AbstractAlgebra: gens
import ..AbstractAlgebra: get_cached!
import ..AbstractAlgebra: hom
import ..AbstractAlgebra: ideal
import ..AbstractAlgebra: ideal_type
import ..AbstractAlgebra: identity_matrix
import ..AbstractAlgebra: image
import ..AbstractAlgebra: image_fn
import ..AbstractAlgebra: inflate
import ..AbstractAlgebra: integral
import ..AbstractAlgebra: inv
import ..AbstractAlgebra: inv!
import ..AbstractAlgebra: is_constant
import ..AbstractAlgebra: is_divisible_by
import ..AbstractAlgebra: is_domain_type
import ..AbstractAlgebra: is_exact_type
import ..AbstractAlgebra: is_finite
import ..AbstractAlgebra: is_gen
import ..AbstractAlgebra: is_monomial
import ..AbstractAlgebra: is_nilpotent
import ..AbstractAlgebra: is_perfect
import ..AbstractAlgebra: is_power
import ..AbstractAlgebra: is_square
import ..AbstractAlgebra: is_squarefree
import ..AbstractAlgebra: is_square_with_sqrt
import ..AbstractAlgebra: is_term
import ..AbstractAlgebra: is_terse
import ..AbstractAlgebra: is_trivial
import ..AbstractAlgebra: is_unit
import ..AbstractAlgebra: is_univariate
import ..AbstractAlgebra: is_univariate_with_data
import ..AbstractAlgebra: is_zero_divisor
import ..AbstractAlgebra: is_zero_divisor_with_annihilator
import ..AbstractAlgebra: isreduced_form
import ..AbstractAlgebra: JuliaRingElement
import ..AbstractAlgebra: leading_coefficient
import ..AbstractAlgebra: leading_exponent_vector
import ..AbstractAlgebra: leading_monomial
import ..AbstractAlgebra: leading_term
import ..AbstractAlgebra: log
import ..AbstractAlgebra: map_coefficients
import ..AbstractAlgebra: matrix
import ..AbstractAlgebra: max_precision
import ..AbstractAlgebra: minpoly
import ..AbstractAlgebra: modulus
import ..AbstractAlgebra: monomials
import ..AbstractAlgebra: monomial!
import ..AbstractAlgebra: mul!
import ..AbstractAlgebra: mul_classical
import ..AbstractAlgebra: mul_karatsuba
import ..AbstractAlgebra: mullow
import ..AbstractAlgebra: neg!
import ..AbstractAlgebra: number_of_columns
import ..AbstractAlgebra: number_of_generators
import ..AbstractAlgebra: number_of_rows
import ..AbstractAlgebra: number_of_variables
import ..AbstractAlgebra: numerator
import ..AbstractAlgebra: one!
import ..AbstractAlgebra: order
import ..AbstractAlgebra: parent_type
import ..AbstractAlgebra: pol_length
import ..AbstractAlgebra: pow!
import ..AbstractAlgebra: preimage
import ..AbstractAlgebra: pretty
import ..AbstractAlgebra: pretty_sort
import ..AbstractAlgebra: primpart
import ..AbstractAlgebra: promote_rule
import ..AbstractAlgebra: pseudorem
import ..AbstractAlgebra: rank_interpolation
import ..AbstractAlgebra: rank_interpolation_mc
import ..AbstractAlgebra: reduce!
import ..AbstractAlgebra: reduced_form
import ..AbstractAlgebra: relations
import ..AbstractAlgebra: rels
import ..AbstractAlgebra: remove
import ..AbstractAlgebra: renormalize!
import ..AbstractAlgebra: set_coefficient!
import ..AbstractAlgebra: set_length!
import ..AbstractAlgebra: set_precision!
import ..AbstractAlgebra: set_valuation!
import ..AbstractAlgebra: shift_left
import ..AbstractAlgebra: shift_right
import ..AbstractAlgebra: snf
import ..AbstractAlgebra: sqrt
import ..AbstractAlgebra: sqrt_classical
import ..AbstractAlgebra: sqrt_classical_char2
import ..AbstractAlgebra: sub!
import ..AbstractAlgebra: submul!
import ..AbstractAlgebra: symbols
import ..AbstractAlgebra: tail
import ..AbstractAlgebra: term_degree
import ..AbstractAlgebra: terms
import ..AbstractAlgebra: term!
import ..AbstractAlgebra: terms_degrees
import ..AbstractAlgebra: terse
import ..AbstractAlgebra: to_univariate
import ..AbstractAlgebra: trailing_coefficient
import ..AbstractAlgebra: transpose
import ..AbstractAlgebra: transpose!
import ..AbstractAlgebra: unit
import ..AbstractAlgebra: use_karamul
import ..AbstractAlgebra: valuation
import ..AbstractAlgebra: var
import ..AbstractAlgebra: var_index
import ..AbstractAlgebra: var_indices
import ..AbstractAlgebra: vars
import ..AbstractAlgebra: vector_space_dim
import ..AbstractAlgebra: zero!
